@@ -188,7 +188,8 @@ class PipelineMetaData:
         pipeline_name = pipeline_name.replace(".", "")
         pipeline_name = project_id + "_" + pipeline_name
         path_to_execute = "".join([dir_name_python, pipeline_name])
-        database_prefix = "davt_" + project_id + "_" + environment
+        # database_prefix = "davt_" + project_id + "_" + environment
+        database_prefix = config["davt_database_name"]
         arg_dictionary["live_prefix"] = live_prefix
         arg_dictionary["environment_for_live"] = environment_for_live
         arg_dictionary["database_prefix"] = database_prefix
